@@ -732,6 +732,13 @@ module Syskit
                 self
             end
 
+            # Declare that an unmanaged task should be used for self
+            def use_unmanaged_task(*spec, **options)
+                invalidate_template
+                deployment_group.use_unmanaged_task(*spec, **options)
+                self
+            end
+
             # Add deployments into the deployments this subnet should be using
             #
             # @param [Models::DeploymentGroup] deployment_group
@@ -897,8 +904,8 @@ module Syskit
 
                 mappings = @template.deep_copy_to(plan)
                 root_task = mappings[@template.root_task]
-                root_task.assign_arguments(arguments.merge(extra_arguments))
-                return model.bind(root_task)
+                root_task.post_instanciation_setup(arguments.merge(extra_arguments))
+                model.bind(root_task)
             end
 
             def has_template?
@@ -907,12 +914,13 @@ module Syskit
 
             # Create a concrete task for this requirement
             def instanciate(plan,
-                context = Syskit::DependencyInjectionContext.new,
-                task_arguments: Hash.new,
-                specialization_hints: Hash.new,
-                use_template: true)
+                            context = Syskit::DependencyInjectionContext.new,
+                            task_arguments: {},
+                            specialization_hints: {},
+                            use_template: true)
 
-                from_cache = context.empty? && specialization_hints.empty? &&
+                from_cache =
+                    context.empty? && specialization_hints.empty? &&
                     use_template && can_use_template?
                 if from_cache
                     task = instanciate_from_template(plan, task_arguments)
@@ -923,13 +931,17 @@ module Syskit
                         context.save
                         context.push(resolved_dependency_injection)
 
-                        task_arguments = self.arguments.merge(task_arguments)
-                        specialization_hints = self.specialization_hints | specialization_hints
-                        task = task_model.instanciate(plan, context,
+                        task_arguments = arguments.merge(task_arguments)
+                        specialization_hints =
+                            self.specialization_hints |
+                            specialization_hints
+                        task = task_model.instanciate(
+                            plan, context,
                             task_arguments: task_arguments,
-                            specialization_hints: specialization_hints)
+                            specialization_hints: specialization_hints
+                        )
                     ensure
-                        context.restore if !from_cache
+                        context.restore unless from_cache
                     end
                 end
 
