@@ -88,10 +88,20 @@ module Syskit
             # Transform the system network into a deployed network
             #
             # This does not access {#real_plan}
-            def compute_deployed_network(compute_policies: true, validate_deployed_network: true)
+            def compute_deployed_network(
+                default_deployment_group: Syskit.conf.deployment_group,
+                compute_policies: true,
+                validate_deployed_network: true
+            )
                 log_timepoint_group 'deploy_system_network' do
-                    SystemNetworkDeployer.new(work_plan, event_logger: event_logger, merge_solver: merge_solver).
-                        deploy(validate: validate_deployed_network)
+                    deployer = SystemNetworkDeployer.new(
+                        work_plan,
+                        event_logger: event_logger,
+                        merge_solver: merge_solver,
+                        default_deployment_group: default_deployment_group
+                    )
+
+                    deployer.deploy(validate: validate_deployed_network)
                 end
 
                 # Now that we have a deployed network, we can compute the
@@ -262,7 +272,7 @@ module Syskit
             # Given the network with deployed tasks, this method looks at how we
             # could adapt the running network to the new one
             def finalize_deployed_tasks
-                debug "finalizing deployed tasks"
+                debug 'finalizing deployed tasks'
 
                 used_deployments = work_plan.find_local_tasks(Deployment).to_set
                 used_tasks       = work_plan.find_local_tasks(Component).to_set
@@ -529,7 +539,7 @@ module Syskit
 
             # Computes the system network, that is the network that fullfills
             # a list of requirements
-            # 
+            #
             # This phase does not interact at all with {#real_plan}. It only
             # computes the canonical plan that matches the requirements.
             #
@@ -548,25 +558,31 @@ module Syskit
             #   corresponding requirement task in the generated plan. In other
             #   words, the keys are in {#real_plan} and the values in
             #   {#work_plan}
-            def resolve_system_network(requirement_tasks,
-                                       garbage_collect: true,
-                                       validate_abstract_network: true,
-                                       validate_generated_network: true,
-                                       validate_deployed_network: true,
-                                       compute_deployments: true,
-                                       compute_policies: true)
+            def resolve_system_network(
+                requirement_tasks,
+                garbage_collect: true,
+                validate_abstract_network: true,
+                validate_generated_network: true,
+                validate_deployed_network: true,
+                compute_deployments: true,
+                default_deployment_group: Syskit.conf.deployment_group,
+                compute_policies: true
+            )
 
                 required_instances = compute_system_network(
                     requirement_tasks,
                     garbage_collect: garbage_collect,
                     validate_abstract_network: validate_abstract_network,
-                    validate_generated_network: validate_generated_network)
+                    validate_generated_network: validate_generated_network
+                )
 
                 if compute_deployments
                     log_timepoint_group 'compute_deployed_network' do
                         compute_deployed_network(
+                            default_deployment_group: default_deployment_group,
                             compute_policies: compute_policies,
-                            validate_deployed_network: validate_deployed_network)
+                            validate_deployed_network: validate_deployed_network
+                        )
                     end
                 end
                 required_instances
@@ -597,6 +613,7 @@ module Syskit
             #   drop the currently generated plan)
             def resolve(requirement_tasks: Engine.discover_requirement_tasks_from_plan(real_plan),
                         on_error: self.class.on_error,
+                        default_deployment_group: Syskit.conf.deployment_group,
                         compute_deployments: true,
                         compute_policies: true,
                         garbage_collect: true,
@@ -611,6 +628,7 @@ module Syskit
                     validate_abstract_network: validate_abstract_network,
                     validate_generated_network: validate_generated_network,
                     compute_deployments: compute_deployments,
+                    default_deployment_group: default_deployment_group,
                     compute_policies: compute_policies,
                     validate_deployed_network: validate_deployed_network)
 
@@ -657,7 +675,8 @@ module Syskit
                 # Finally, we should now only have deployed tasks. Verify it
                 # and compute the connection policies
                 if garbage_collect && validate_final_network
-                    validate_final_network(required_instances, work_plan, compute_deployments: compute_deployments)
+                    validate_final_network(required_instances, work_plan,
+                                           compute_deployments: compute_deployments)
                     log_timepoint 'validate_final_network'
                 end
 
